# This is a -*- Tcl -*- library script and belongs to the
# `Jumble Library for Tcl and Friends'.
#
# string.tcl --- String manipulation functions
#
# Copyright (C) 1996 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
# Version: 0.0a3
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
# 
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

# ---------------------------------------------------
# juf_strcasecmp - case insensitive string comparison
#
# in:	string1, string2	strings to compare
# out:	similar to `string compare'
# ---------------------------------------------------

proc juf_strcasecmp {string1 string2} {
	string compare [string tolower $string1] [string tolower $string2]
}

# --------------------------------------------------------------------------
# juf_split STRING [EXP LIMIT]
#
# Returns a list created by splitting STRING at each match
# of the regular expression EXP. If EXP is omitted  
# or an empty string is given, it defaults to whitespace. If LIMIT
# is given, it stops the matching process, so that the size of the resulting
# list is equal or lesser than LIMIT.
# --------------------------------------------------------------------------

proc juf_split {string {exp ""} {limit ""}} {
	#
	# default regular expression (should match a sequence of whitespace)
	#
	if {$exp == ""} {
		set exp "\[\t\r\n ]+"
	}
	#
	# initializations
	#
	if {$limit != "" && $limit <= 0} {return ""}
	set v_rmd $string
	set v_list ""
	#
	# loop through
	#
	while {[regexp -indices -- $exp $v_rmd v_res]} {
		#
		# maximum number of elements reached ?
		#
		if {$limit != ""} {
			if {[expr [llength $v_list] + 1] == $limit} {
				lappend v_list $v_rmd
				return $v_list 
			}
		}
		#
		# if start of string doesn't match, we
		# have an element of the resulting list
		#
		if {[lindex $v_res 0] != 0} {
			lappend v_list [string range $v_rmd 0 \
					[expr [lindex $v_res 0] - 1]]
		}
		#
		# create and check remainder of string
		#
		set v_rmd [string range $v_rmd [expr [lindex $v_res 1] + 1] end]
		if {$v_rmd == ""} {return $v_list}
	}
	#
	# add remainder of string to result
	#
	lappend v_list $v_rmd
}
	

